Function Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

C |
| copy, $.jqplot.ThemeEngine
D |
| destroy, jqPlot
| draw $.jqplot.shadowRenderer$.jqplot.shapeRenderer jqPlot
| drawSeries, jqPlot
G |
| get, $.jqplot.ThemeEngine
| getThemeNames, $.jqplot.ThemeEngine
| getThemes, $.jqplot.ThemeEngine
I |
| init, jqPlot
M |
| makeGridData $.jqplot.BezierCurveRenderer.js$.jqplot.MekkoRenderer
| moveBlock, $.jqplot.BlockRenderer
| moveSeriesToBack, jqPlot
| moveSeriesToFront, jqPlot
N |
| newTheme, $.jqplot.ThemeEngine
Q |
| quickInit, jqPlot
R |
| redraw, jqPlot
| reInitialize, jqPlot
| remove, $.jqplot.ThemeEngine
| rename, $.jqplot.ThemeEngine
| replot, jqPlot
| resetAxesScale, jqPlot
| restoreOriginalSeriesOrder, jqPlot
| restorePreviousSeriesOrder, jqPlot
S |
| setGridData $.jqplot.BezierCurveRenderer.js$.jqplot.MekkoRenderer
Z |
| zoomProxy, $.jqplot.Cursor.$.jqplot.Cursor

> $.jqplot.ThemeEngine.prototype.copy = function ( | sourceName,
> | targetName,
> | obj | )

Create a copy of an existing theme in the themeEngine, adding it the themeEngine.

> this.destroy = function()

Releases all resources occupied by the plot

> $.jqplot.ShadowRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws an transparent black (i.e.

> $.jqplot.ShapeRenderer.prototype.draw = function( | ctx,
> | points,
> | options | )

draws the shape.

> this.draw = function()

Draws all elements of the plot into the container.

> this.drawSeries = function( | options,
> | idx | )

Redraws all or just one series on the plot.

> $.jqplot.ThemeEngine.prototype.get = function( | name | )

Get and return the named theme or the active theme if no name given.

> $.jqplot.ThemeEngine.prototype.getThemeNames = function()

Return the list of theme names in this manager in alpha-numerical order.

> $.jqplot.ThemeEngine.prototype.getThemes = function()

Return a list of themes in alpha-numerical order by name.

> this.init = function( | target,
> | data,
> | options | )

sets the plot target, checks data and applies user options to plot.

> $.jqplot.BezierCurveRenderer.prototype.makeGridData = function( | data,
> | plot | )

converts any arbitrary data values to grid coordinates and returns them.

> $.jqplot.MekkoRenderer.prototype.makeGridData = function( | data,
> | plot | )

converts any arbitrary data values to grid coordinates and returns them.

> this.moveBlock = function ( | idx,
> | x,
> | y,
> | duration | )

Moves an individual block.

> this.moveSeriesToBack = function ( | idx | )

This method requires jQuery 1.4+ Moves the specified series canvas behind all other series canvases.

> this.moveSeriesToFront = function ( | idx | )

This method requires jQuery 1.4+ Moves the specified series canvas in front of all other series canvases.

> $.jqplot.ThemeEngine.prototype.newTheme = function( | name,
> | obj | )

Create a new theme based on the default theme, adding it the themeEngine.

> this.quickInit = function ()

Quick reinitialization plot for replotting.

> this.redraw = function( | clear | )

Empties the plot target div and redraws the plot.

> this.reInitialize = function ( | data,
> | opts | )

reinitialize plot for replotting.

> $.jqplot.ThemeEngine.prototype.remove = function( | name | )

Remove the given theme from the themeEngine.

> $.jqplot.ThemeEngine.prototype.rename = function ( | oldName,
> | newName | )

Rename a theme.

> this.replot = function( | options | )

Does a reinitialization of the plot followed by a redraw.

> this.resetAxesScale = function( | axes,
> | options | )

Reset the specified axes min, max, numberTicks and tickInterval properties to null or reset these properties on all axes if no list of axes is provided.

> this.restoreOriginalSeriesOrder = function ()

This method requires jQuery 1.4+ Restore the series canvas order to its original order when the plot was created.

> this.restorePreviousSeriesOrder = function ()

This method requires jQuery 1.4+ Restore the series canvas order to its previous state.

> $.jqplot.BezierCurveRenderer.prototype.setGridData = function( | plot | )

converts the user data values to grid coordinates and stores them in the gridData array.

> $.jqplot.MekkoRenderer.prototype.setGridData = function( | plot | )

converts the user data values to grid coordinates and stores them in the gridData array.

> $.jqplot.Cursor.zoomProxy = function( | targetPlot,
> | controllerPlot | )

links targetPlot to controllerPlot so that plot zooming of targetPlot will be controlled by zooming on the controllerPlot.
Close